# 📰 Nudebomb News

## v0.2.0

- Features

  - Ignore option

## v0.1.3

- Fixes

  - Fix timestamps not recording sometimes.

## v0.1.2

- Fixes

  - Timestamps more resilient to errors.

## v0.1.1

- Fixes

  - Fix treestamps type issue.
  - Timestamps do not set on dry run.

## v0.1.0

_First Release_
